#ifndef NVIM_EVAL_DECODE_H
#define NVIM_EVAL_DECODE_H

#include <stddef.h>

#include <msgpack.h>

#include "nvim/eval/typval.h"

#ifdef INCLUDE_GENERATED_DECLARATIONS
# include "eval/decode.h.generated.h"
#endif
#endif  // NVIM_EVAL_DECODE_H
